#!/bin/sh

export SGX_SDK=./build/vroot/sgxsdk

test -n "$SGX_VERIFY_AE_DEBUG" || SGX_VERIFY_AE_DEBUG=0

# The key is used to sign the unsigned enclave. The two
# signed enclaves are then compared, minus the signature
# Doesn't matter what key we use, anything is fine
key=./psw/ae/ref_le/ref_keys/le_private_test_key.pem
   
test -n "$1" || { echo "Missing path to signed enclave"; exit 1; }
test -n "$2" || { echo "Missing path to unsigned enclave"; exit 1; }
test -n "$3" || { echo "Missing path to signing config"; exit 1; }

signed=$1
unsigned=$2
config=$3

test -f $signed || { echo "Signed enclave '$signed' does not exist"; exit 1; }
test -f $unsigned || { echo "Unsigned enclave '$unsigned' does not exist"; exit 1; }
test -f $config || { echo "Signing config '$config' doest not exist"; exit 1; }

echo -n "Verify $(basename $unsigned): "

./linux/reproducibility/ae_reproducibility_verifier/reproducibility_verifier.sh $signed $unsigned $key $config 1>log.txt 2>&1

if test $SGX_VERIFY_AE_DEBUG = "1"
then
    echo
    cat log.txt
fi

# Search for line matching
#
#  Reproducibility Verification FAILED! 
#  Reproducibility Verification PASSED! 
res=$(grep "Reproducibility Verification" log.txt | awk '{print $3}' | sed -e 's/!//')
echo $res

if test $res = "FAILED"
then
    if test $SGX_VERIFY_AE_DEBUG = "1"
    then
       cat output/metadata_diff.txt
    fi
    exit 1
fi

exit 0
